#ifndef STDBOOL_H_
#define STDBOOL_H_

/**
 * stdbool.h - ISO C99 Boolean type
 *
 * In ISO C99, stdbool.h is a standard header and _Bool is a keyword, but
 * some compilers don't offer these yet. This header file is an
 * implementation of the standard ISO C99 stdbool.h header file. It checks
 * for various compiler versions and defines things that are missing in
 * those versions. Sizeof(_Bool) evaluates to 1, which follows from C99's definition that
 * _Bool is only as large as necessary to hold its two possible values.
 *
 * The GNU and Watcom compilers include a stdbool.h, but the Borland
 * C/C++ 5.5.1 compiler and the Microsoft compilers do not.
   */

#ifdef __cplusplus
typedef bool _Bool;
#else

/**
 * Borland C++ 5.5.1 does not define _Bool.
 */
#ifdef __BORLANDC__
typedef char _Bool;
#endif /* __BORLANDC__ */

/**
 * Microsoft C/C++ does not define _Bool.
 * Microsoft define _Bool in C++ only, but not as a native type.
 * It is simply a typedef for bool defined in the yvals.h header.
 */
#ifdef _MSC_VER
typedef char _Bool;
#endif /* _MSC_VER */

#define bool _Bool
#define false 0
#define true 1

#endif /* __cplusplus */

/**
 * Signal that all the definitions are present.
 */
#define __bool_true_false_are_defined 1

#endif /* STDBOOL_H_ */