///
/// \file grdidapi.h
/// \brief Guardant ID API
///
/// This module contains the function prototypes and constant, type and
/// structure definitions for the Guardant ID API.
///

#ifndef GRD_ID_API_H_
#define GRD_ID_API_H_

#include "rqst_gid.h"
#include "typesC99.h"

#ifdef _WIN32
#define GRD_API __stdcall
#else
#define GRD_API
#endif // _WIN32

///      Guardant ID.       /ref grdOpen
typedef uint32_t GrdHandle;

///    Guardant ID
typedef struct
{
	uint8_t hrdVersionHi;    ///<    Guardant ID (major)
	uint8_t hrdVersionLo;    ///<    Guardant ID (minor)
	uint8_t protocolNumber;  ///<     Guardant ID
	uint8_t programNumber;   ///<    Guardant ID
	uint8_t standardNumber;  ///<   Guardant ID (0-)
	uint32_t memLenInBytes;  ///< ߣ  ( )
	uint32_t pinOffset;      ///<  PIN-   
	uint32_t configOffset;   ///<      
	uint64_t dongleId;       ///< (ID)  (8 ) *BY VAL - USE CPU<->LE
} GrdIdInfo;

///   
static const uint32_t GrdInvalidHandle = 0xFFFFFFFF;

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

	///        Guardant ID
	/// \param index    Guardant ID   ( 0  127)
	/// \return   :      Guardant ID,     \c INVALID_HANDLE
	GrdHandle GRD_API grdOpen(uint8_t index);
	///     \ref GrdIdInfo    ,   
	/// \param handle   
	/// \param info    \ref GrdIdInfo
	/// \param infoSize       info
	/// \return   :   ,      
	uint32_t GRD_API grdGetInfo(GrdHandle handle, GrdIdInfo* info, uint32_t infoSize);
	///      Guardant ID,   PIN-    PIN- 
	///  /
	/// \param handle   
	/// \param masterPin   PIN-
	/// \param newPin       PIN-  NULL   PIN-  
	/// \param newPinSize  PIN-   ( 32 )
	/// \param usePin   PIN-   /
	/// \return   :   ,      
	uint32_t GRD_API grdInitialize(GrdHandle handle, uint32_t masterPin, const void* newPin, uint32_t newPinSize, bool usePin);
	///        Guardant ID
	/// \param handle   
	/// \param pin      PIN-  NULL   PIN-  
	/// \param pinSize  PIN-  
	/// \param offset      ( )
	/// \param buf        
	/// \param bytesToRead    
	/// \return   :   ,      
	uint32_t GRD_API grdRead(GrdHandle handle, const void* pin, uint32_t pinSize, uint32_t offset, void* buf, uint32_t bytesToRead);
	///        Guardant ID.       ,
	///   
	/// \param pin      PIN-  NULL   PIN-  
	/// \param pinSize  PIN-  
	/// \param offset      ( )
	/// \param buf       
	/// \param bytesToWrite    
	/// \return   :   ,      
	uint32_t GRD_API grdWrite(GrdHandle handle, const void* pin, uint32_t pinSize, uint32_t offset, const void* buf, uint32_t bytesToWrite);
	///      Guardant ID.         API
	/// \param handle   
	/// \param ptrGID    \ref TDRVREQUEST_GID
	/// \param size   \ref TDRVREQUEST_GID (   \ref TDRVREQUEST_GID_HDR)
	/// \return   :  true,     false
	bool GRD_API grdCommand(GrdHandle handle, void* ptrGID, uint32_t size);
	///       
	/// \param handle   
	/// \return   :   ,      
	uint32_t GRD_API grdClose(GrdHandle handle);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // GRD_ID_API_H_
