#ifndef RQST_GID_H__
#define RQST_GID_H__

#include "typesC99.h"

//   Guardant ID 256
#define GID_MEM_SIZE_256        0x100                   //    
#define GID_MEM_SIZE_256_W      GID_MEM_SIZE_256/2      //    
#define GID_MEM_SIZE_256_P      GID_MEM_SIZE_256/256    //    
//   Guardant ID 16K
#define GID_MEM_SIZE_16K        0x4000                  //    
#define GID_MEM_SIZE_16K_W      GID_MEM_SIZE_16K/2      //    
#define GID_MEM_SIZE_16K_P      GID_MEM_SIZE_16K/256    //    

#define MASTER_PIN_LEN          4                       //   MasterPIN  
#define PIN_LEN                 32                      //    PIN  
#define ID_LEN                  8                       //  ID  

/*- Master PIN- Guardant ID ------------------------------------------*/
#define GIDMST_0                0x29
#define GIDMST_1                0xF1
#define GIDMST_2                0x14
#define GIDMST_3                0x79

#define GIDMST                  0x7914F129

/*-  Guardant ID -------------------------------------------------*/
#define GIDCMD_GetInfo          0x30
#define GIDCMD_ReadWords        0x31
#define GIDCMD_WriteWords       0x32
#define GIDCMD_Initialize       0x33

/*-   Guardant ID -------------------------------------------*/
#define GIDRET_Ok               0    //   
#define GIDRET_NotFound         1    // Guardant ID   PIN  
#define GIDRET_ComErr           2    //    
#define GIDRET_ArgsErr          3    //     
#define GIDRET_VerifyErr        4    //   /   
#define GIDRET_ProtErr          5    //     Guardant ID
#define GIDRET_Busy             6    // Guardant ID    
#define GIDRET_ProtocolNotSup   7    //  Guardant ID 
                                     // (      Guardant ID)
#define GIDRET_DriverBusy       8    //      
#define GIDRET_InvalidHandle    9    //   Guardant ID API

/*-   Guardant ID ( ) --------------------------------*/
// Guardant ID 256
#define GIDADDR_CFG_256_W       GID_MEM_SIZE_256 - 1            //   
#define GIDADDR_PIN_256_W       GIDADDR_CFG_W_256 - (PIN_LEN/2) //  PIN-
// Guardant ID 16K
#define GIDADDR_CFG_16K_W       GID_MEM_SIZE_16K - 1            //   
#define GIDADDR_PIN_16K_W       GIDADDR_CFG_W_16K - (PIN_LEN/2) //  PIN-

/*-    -------------------------------------------*/
#define GIDCFG_PIN_USE_FLAG     1           //  " PIN"
#define GIDCFG_PIN_LEN_MASK     00111110b   // ,   PIN-

/*-      Guardant ID ---------------------------*/
// .
typedef struct _TDRVREQUEST_GID_HDR
{
	uint8_t     byCmd;          //[in]      Guardant ID
	uint8_t     byRes1;         //[in]      ( ?)
	uint8_t     abyRes2[6];     //         
	uint8_t     abyPIN[32];     //[in]     PIN-  Master PIN- *PIN is a sequence of bytes (not a VAL)
	uint8_t     abyRes3[8];     //         
	uint16_t    wAddrToRW;      //[in]         /
	uint16_t    wDataLenW;      //[in]     -   /
	uint8_t     abyRes6[4];     //         
	uint8_t     abyID[8];       //[in/out] ID  Guardant ID
	uint8_t     byRetCode;      //[out]      Guardant ID
	uint8_t     byHVer;         //[out]      Guardant ID (maj:min)
	uint8_t     byNProt;        //[out]    #    Guardant ID
	uint8_t     byNProg;        //[out]    #   Guardant ID
	uint8_t     byNStd;         //[out]    #  Guardant ID (0-)
	uint8_t     byMemLen;       //[out]       16- 
	                            //         ( Guardant ID   #1)
	                            //            256- 
	                            //         ( Guardant ID   #2+)
	uint8_t     abyRes7[58];    //         
} TDRVREQUEST_GID_HDR;

//     Guardant ID.    ,
// ,     abyData,   
//      
typedef struct _TDRVREQUEST_GID
{
	TDRVREQUEST_GID_HDR HDR;                   //  
	uint8_t        abyData[GID_MEM_SIZE_16K];  // ,    
	// ,   Guardant ID
} TDRVREQUEST_GID;

#endif	//RQST_GID_H__
